@@ -55,7 +55,8 @@ credentials_questions = [
         "choices": [
             Choice("https://elearn5.ut.ac.ir", name="University of Tehran"),
             Choice("https://lms.khu.ac.ir", name="Kharazmi University"),
-            Choice("https://lms3.sbu.ac.ir/", name="Shahid Beheshti University"),
+            Choice("https://lms3.sbu.ac.ir", name="Shahid Beheshti University"),
+            Choice("https://lms.iust.ac.ir", name="Iran University of Science and Technology"),
         ],
     },
     {
